<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: POST");
header("Content-Type: application/json");

require_once 'config.php';

// Function to send API requests to DPO





function sendDPORequest($xmlRequest) {
   
    
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, DPO_ENDPOINT);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $xmlRequest);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, ["Content-Type: application/xml"]);

    $response = curl_exec($ch);
    if ($response === false) {
        error_log("cURL Error: " . curl_error($ch));
        curl_close($ch);
        return false;
    }

    curl_close($ch);

    $xml = simplexml_load_string($response);
    if ($xml === false) {
        error_log("Invalid XML Response: " . $response);
        return false;
    }

    return $xml;
}

// Get request data
$data = json_decode(file_get_contents("php://input"), true);
if (!isset($data["email"])) {
    echo json_encode(["error" => "Missing email"]);
    exit;
}

// Connect to database
$pdo = new PDO("mysql:host=" . DATABASE_HOST . ";dbname=" . DATABASE_NAME, DATABASE_USER, DATABASE_PASSWORD);
$pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

// Retrieve subscription token and customer token
$stmt = $pdo->prepare("SELECT subscription_token, trans_token FROM transactions WHERE email = :email AND is_recurring = 1");
$stmt->execute([':email' => $data["email"]]);
$subscription = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$subscription) {
    echo json_encode(["error" => "No active subscription found"]);
    exit;
}

$subscriptionToken = $subscription["subscription_token"];
$customerToken = $subscription["trans_token"]; // Assuming trans_token is used as customer token in DPO

// **Step 1: Delete the saved card**
$xmlRequest = '<?xml version="1.0" encoding="utf-8"?>
<API3G>
    <CompanyToken>' . COMPANY_TOKEN . '</CompanyToken>
    <Request>deleteCard</Request>
    <customerToken>' . htmlspecialchars($customerToken) . '</customerToken>
    <subscriptionToken>' . htmlspecialchars($subscriptionToken) . '</subscriptionToken>
</API3G>';



$response = sendDPORequest($xmlRequest);
$resultCode = (int) $response->Result;
// **Step 2: Check if deletion was successful**
if ($resultCode === 0) {
    // **Step 3: Mark subscription as cancelled and remove subscription_token**
    $update = $pdo->prepare("UPDATE transactions SET is_recurring = 0, transaction_status = 'Auto-renewal cancelled', subscription_token = NULL WHERE email = :email");
    $update->execute([':email' => $data["email"]]);

    echo json_encode(["success" => "Auto-renewal cancelled successfully"]);
} else {
    echo json_encode(["error" => "Failed to delete card: " . $response->ResultExplanation]);
}
exit;
?>
