<?php
require_once 'config.php';

// Connect to database
$pdo = new PDO("mysql:host=" . DATABASE_HOST . ";dbname=" . DATABASE_NAME, DATABASE_USER, DATABASE_PASSWORD);
$pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

// Get all active subscriptions
$sql = "SELECT * FROM transactions WHERE is_recurring = 1 AND expiry_date >= CURDATE()";
$stmt = $pdo->prepare($sql);
$stmt->execute();
$subscriptions = $stmt->fetchAll(PDO::FETCH_ASSOC);

foreach ($subscriptions as $sub) {
    $email = htmlspecialchars($sub['email']); 

    // Step 1: Retrieve payer's subscription token
    $subscriptionResponse = sendDPORequest('<API3G>
        <CompanyToken>' . htmlspecialchars($sub['company_token']) . '</CompanyToken>
        <Request>getSubscriptionToken</Request>
        <SearchCriteria>1</SearchCriteria>
        <SearchCriteriaValue>' . $email . '</SearchCriteriaValue>
    </API3G>');

    // Check for valid response
    if ((int) $subscriptionResponse->Result === 0) {
        $subscriptionToken = (string) $subscriptionResponse->SubscriptionToken;
        $customerToken = (string) $subscriptionResponse->CustomerToken;
    } else {
        error_log("Failed to get subscription token for email $email: " . $subscriptionResponse->ResultExplanation);
        continue; // Skip to the next subscription
    }

    // Step 2: Create transaction with amount payable
    $redirectURL = BASE_URL . "/membership/payment_success.php";
    $backURL = BASE_URL . "/membership/payment_failed.php";
 
    $xmlRequest_Create = '<?xml version="1.0" encoding="utf-8"?>
    <API3G>
       <CompanyToken>' . htmlspecialchars($sub['company_token']) . '</CompanyToken>
        <Request>createToken</Request>
        <Transaction>
            <PaymentAmount>' . htmlspecialchars($sub['amount']) . '</PaymentAmount>
            <PaymentCurrency>ZMW</PaymentCurrency>
            <CompanyRef>' . htmlspecialchars($sub['company_ref']) . '</CompanyRef>
            <RedirectURL>' . htmlspecialchars($redirectURL) . '</RedirectURL>
            <BackURL>' . htmlspecialchars($backURL) . '</BackURL>
            <customerFirstName>' . htmlspecialchars($sub['first_name']) . '</customerFirstName>
            <customerLastName>' . htmlspecialchars($sub['last_name']) . '</customerLastName>
            <customerEmail>' . htmlspecialchars($sub['email']) . '</customerEmail>
            <customerPhone>' . htmlspecialchars($sub['phone']) . '</customerPhone>
            <CompanyRefUnique>0</CompanyRefUnique>
        </Transaction>
        <Services>
            <Service>
                <ServiceType>' . SERVICE_TYPE . '</ServiceType>
                <ServiceDescription>Payment for services</ServiceDescription>
                <ServiceDate>' . date('Y-m-d H:i:s') . '</ServiceDate>
            </Service>
        </Services>
    </API3G>';

    $response = sendDPORequest($xmlRequest_Create);
    if ((int) $response->Result !== 0) {
        error_log("Transaction creation failed for Subscription ID " . $sub['id'] . ": " . $response->ResultExplanation);
        continue; // Skip to the next subscription
    }

    $transToken = (string) $response->TransToken;

    // Step 3: Charge customer using chargeTokenRecurrent
    $xmlRequest_Charge = '<API3G>
        <CompanyToken>' . htmlspecialchars($sub['company_token']) . '</CompanyToken>
        <Request>chargeTokenRecurrent</Request>
        <TransactionToken>' . htmlspecialchars($transToken) . '</TransactionToken>
        <subscriptionToken>' . htmlspecialchars($subscriptionToken) . '</subscriptionToken>
    </API3G>';

    $response = sendDPORequest($xmlRequest_Charge);

    if ((int) $response->Result === 0) { // Transaction successful
        // Extend expiry date dynamically based on subscription_period
        $subscriptionPeriod = (int) $sub['subscription_period']; // Ensure it's an integer
        $newExpiryDate = date('Y-m-d', strtotime("+$subscriptionPeriod days", strtotime($sub['expiry_date'])));

        // Update transaction status, expiry date, subscription token, and transaction token
        $update = $pdo->prepare("UPDATE transactions SET 
            transaction_status = 'Transaction Paid', 
            expiry_date = :expiry_date, 
            subscription_token = :subscription_token, 
            trans_token = :trans_token
            WHERE id = :id");
        $update->execute([
            ':expiry_date' => $newExpiryDate,
            ':subscription_token' => $subscriptionToken,
            ':trans_token' => $transToken,
            ':id' => $sub['id']
        ]);

        error_log("Subscription ID " . $sub['id'] . " renewed successfully.");
    } else {
        error_log("Transaction failed for Subscription ID " . $sub['id'] . ": " . $response->ResultExplanation);
    }
}

/**
 * Sends a request to the DPO API.
 */
function sendDPORequest($xmlRequest) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, DPO_ENDPOINT);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $xmlRequest);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, ["Content-Type: application/xml"]);

    $response = curl_exec($ch);
    if ($response === false) {
        error_log("cURL Error: " . curl_error($ch));
        curl_close($ch);
        return false;
    }

    curl_close($ch);

    $xml = simplexml_load_string($response);
    if ($xml === false) {
        error_log("Invalid XML Response: " . $response);
        return false;
    }

    return $xml;
}
?>
