<?php
require 'vendor/autoload.php'; // Include PHPMailer and PhpSpreadsheet
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;
use PHPMailer\PHPMailer\SMTP;

require_once 'config.php';


// Proceed with your database connection
$host = DATABASE_HOST;
$dbname = DATABASE_NAME;
$username = DATABASE_USER;
$password = DATABASE_PASSWORD;
$emailRecipient = ADMIN_EMAIL_ADDRESS;
$dsn = "mysql:host=$host;dbname=$dbname;charset=utf8";

try {
    $pdo = new PDO($dsn, $username, $password, [PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION]);
    $today = date('Y-m-d');
    $sql = "SELECT * FROM transactions WHERE DATE(expiry_date) = :today AND  result_code = '000'"; 
    $stmt = $pdo->prepare($sql);
    $stmt->execute(['today' => $today]);
    $transactions = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    if (count($transactions) > 0) {
        // Create Excel file
        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();
        
        // Add headers
        $headers = array_keys($transactions[0]);
        $sheet->fromArray($headers, NULL, 'A1');
        
        // Add data rows
        $rowNum = 2;
        foreach ($transactions as $transaction) {
            $sheet->fromArray(array_values($transaction), NULL, 'A' . $rowNum);
            $rowNum++;
        }
        
        $filePath = __DIR__ . "/expired_subscriptions/expired_subscriptions_$today.xlsx";
        $writer = new Xlsx($spreadsheet);
        $writer->save($filePath);

        // Send Email
       // Send Email
                        $mail = new PHPMailer(true);
                        try {
                            // SMTP configuration
                            $mail->isSMTP();
                            $mail->Host = SMTP_HOST;
                            $mail->SMTPAuth = true;
                            $mail->Username = SMTP_USERNAME;
                            $mail->Password = SMTP_PASSWORD;
                            // For SSL
                            $mail->SMTPSecure = PHPMailer::ENCRYPTION_SMTPS; // Use SSL
                            $mail->Port = SMTP_PORT;
                            // Email details
                            $mail->setFrom(SMTP_USERNAME, 'DONEDeal POS');
                            $mail->addAddress($emailRecipient);
                            $mail->Subject = 'Expired Subscriptions Report';
                            $mail->Body = 'Attached is the expired subscriptions report for ' . $today;
                            $mail->addAttachment($filePath);

                            $mail->send();
                            error_log('Email sent successfully to ' . $emailRecipient);
                        } catch (Exception $e) {
                            error_log('Email error: ' . $mail->ErrorInfo);
                        }

    } else {
        error_log('No expired subscriptions found for ' . $today);
    }
} catch (PDOException $e) {
    error_log('Database error: ' . $e->getMessage());
}
