<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: POST");
header("Content-Type: application/json");

require_once 'vendor/autoload.php';
require_once 'config.php';

// Database & API Configuration
$host = DATABASE_HOST;
$dbname = DATABASE_NAME;
$username = DATABASE_USER;
$password = DATABASE_PASSWORD;
$base_url = BASE_URL;
$dpo_endpoint = DPO_ENDPOINT;
$company_token = COMPANY_TOKEN;
$serviceType = SERVICE_TYPE;

// Function to send API requests to DPO
function sendDPORequest($xmlRequest) {
    global $dpo_endpoint;
    
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $dpo_endpoint);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $xmlRequest);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, ["Content-Type: application/xml"]);

    $response = curl_exec($ch);
    curl_close($ch);

    return simplexml_load_string($response);
}

// Get request data
$data = json_decode(file_get_contents("php://input"), true);
if (!$data) {
    echo json_encode(["error" => "Invalid request."]);
    exit;
}

// Validate required fields
if (!isset($data["amount"], $data["email"], $data["firstName"], $data["lastName"], $data["phone"], $data["subscriptionPeriod"], $data["isRecurring"])) {
    echo json_encode(["error" => "Missing transaction details"]);
    exit;
}

// Extract user data
$amount = $data["amount"];
$email = $data["email"];
$firstName = $data["firstName"];
$lastName = $data["lastName"];
$phone = $data["phone"];
$subscriptionPeriod = $data["subscriptionPeriod"];
$isRecurring = $data["isRecurring"];
$expiryDate = date('Y-m-d', strtotime("+$subscriptionPeriod days"));
$companyRef = "ref-" . time();

// DPO Payment URLs
$redirectURL = "$base_url/membership/payment_success.php";
$backURL = "$base_url/membership/payment_failed.php";

// Create transaction request XML
$xmlRequest = '<?xml version="1.0" encoding="utf-8"?>
<API3G>
    <CompanyToken>' . $company_token . '</CompanyToken>
    <Request>createToken</Request>
    <Transaction>
        <PaymentAmount>' . htmlspecialchars($amount) . '</PaymentAmount>
        <PaymentCurrency>ZMW</PaymentCurrency>
        <CompanyRef>' . htmlspecialchars($companyRef) . '</CompanyRef>
        <RedirectURL>' . htmlspecialchars($redirectURL) . '</RedirectURL>
        <BackURL>' . htmlspecialchars($backURL) . '</BackURL>
        <customerFirstName>' . htmlspecialchars($firstName) . '</customerFirstName>
        <customerLastName>' . htmlspecialchars($lastName) . '</customerLastName>
        <customerEmail>' . htmlspecialchars($email) . '</customerEmail>
        <customerPhone>' . htmlspecialchars($phone) . '</customerPhone>
        <CompanyRefUnique>0</CompanyRefUnique>
        <AllowRecurrent>' . $isRecurring . '</AllowRecurrent>
    </Transaction>
</API3G>';

$response = sendDPORequest($xmlRequest);
if ($response->Result !== "000") {
    echo json_encode(["error" => "Transaction failed: " . $response->ResultExplanation]);
    exit;
}

$transToken = (string) $response->TransToken;
$subscriptionToken = null;

// If recurring, retrieve subscription token
if ($isRecurring == 1) {
    $subscriptionResponse = sendDPORequest('<API3G>
        <CompanyToken>' . $company_token . '</CompanyToken>
        <Request>getSubscriptionToken</Request>
        <SearchCriteria>1</SearchCriteria>
        <SearchCriteriaValue>' . htmlspecialchars($email) . '</SearchCriteriaValue>
    </API3G>');

    if ($subscriptionResponse->Result == "000") {
        $subscriptionToken = (string)$subscriptionResponse->SubscriptionToken;
    }
}

// Store transaction in the database
try {
    $pdo = new PDO("mysql:host=$host;dbname=$dbname", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    $stmt = $pdo->prepare("
        INSERT INTO transactions (company_ref, amount, email, first_name, last_name, phone, subscription_period, is_recurring, trans_token, company_token, transaction_status, expiry_date, subscription_token)
        VALUES (:company_ref, :amount, :email, :first_name, :last_name, :phone, :subscription_period, :is_recurring, :trans_token, :company_token, :transaction_status, :expiry_date, :subscription_token)
    ");

    $stmt->execute([
        ':company_ref' => $companyRef,
        ':amount' => $amount,
        ':email' => $email,
        ':first_name' => $firstName,
        ':last_name' => $lastName,
        ':phone' => $phone,
        ':subscription_period' => $subscriptionPeriod,
        ':is_recurring' => $isRecurring,
        ':trans_token' => $transToken,
        ':company_token' => $company_token,
        ':transaction_status' => 'initiated',
        ':expiry_date' => $expiryDate,
        ':subscription_token' => $subscriptionToken
    ]);

    echo json_encode(["transToken" => $transToken, "subscriptionToken" => $subscriptionToken]);
    exit;
} catch (PDOException $e) {
    echo json_encode(["error" => "Failed to save transaction: " . $e->getMessage()]);
    exit;
}
?>
