<?php
require_once 'vendor/autoload.php';
require_once 'config.php';
// Proceed with your database connection
$host = DATABASE_HOST;
$dbname = DATABASE_NAME;
$username = DATABASE_USER;
$password = DATABASE_PASSWORD;
$base_url = BASE_URL;
$serviceType = SERVICE_TYPE;

// Database connection string (DSN)
$dsn = "mysql:host=$host;dbname=$dbname;charset=utf8";

// Optional: Test the PDO connection using the retrieved values
try {
    $pdo = new PDO($dsn, $username, $password, [PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION]);
  
    // Example query to test the connection
    $sql = "SELECT duration_days, plan_name, price FROM subscription_pricing";
    $stmt = $pdo->query($sql);
    $subscriptions = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Ensure $subscriptions is an array (it can be empty if no results are returned)
    if (!$subscriptions) {
        $subscriptions = [];
    }
} catch (PDOException $e) {
    die("Database error: " . $e->getMessage());
}
?>


<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title>Welcome To buyingpropertyinzambia.com</title>
    <link
      href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.0-beta2/dist/css/bootstrap.min.css"
      rel="stylesheet"
    />
    <style>
      .menu-item {
        color: purple;
        border: 1px solid purple;
        padding: 5px 10px;
        border-radius: 5px;
        margin: 0 5px;
      }
      .centered-form {
        min-height: calc(100vh - 250px);
      }
      .no-border {
        border: none;
        background-color: transparent;
        outline: none;
      }

      .no-border[readonly] {
        background-color: transparent;
      }

      .d-flex {
        display: flex;
      }

      .align-items-center {
        align-items: center;
      }

      .me-2 {
        margin-right: 0.2rem; /* Adjust the margin as needed */
      }

      .fixed-width-label {
        white-space: nowrap;
        width: 80px; /* Adjust the width as needed */
      }

      .flex-grow-1 {
        flex-grow: 1;
      }

      .buttont {
        background-color: #622d80;
        border: 0;
      }

      .buttont:hover {
        background-color: #c39bd3; /* A light shade of purple */
      }
    </style>
    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
  </head>
  <body>
    <header class="bg-light py-3">
      <div class="container">
        <div class="d-flex flex-wrap align-items-center">
          <div class="logo">
            <img src="assets/img/logo.png" alt="Logo" class="img-fluid" />
          </div>
          <nav class="ms-auto">
            <ul class="nav">
              <li class="nav-item">
                <a
                  class="nav-link menu-item"
                  href="https://buyingpropertyinzambia.com/"
                  >Home</a
                >
              </li>
            </ul>
          </nav>
        </div>
      </div>
    </header>

    <div class="container d-flex justify-content-center align-items-center centered-form">
  <div class="w-50 w-sm-100">
    <div class="card shadow-lg p-4">
      <form id="paymentForm" action="script/paypal_process.php" method="post" onsubmit="handlePayment(event)">
        <p style="text-align: center; color: red">
          <strong>NOTE:</strong> All fields marked with <span style="color: red">*</span> are required.
        </p>
        <div class="mb-3">
          <label for="firstName" class="form-label">First Name <span style="color: red">*</span></label>
          <input type="text" class="form-control" id="firstName" placeholder="Enter your First Name" name="firstName" required />
        </div>

        <div class="mb-3">
          <label for="lastName" class="form-label">Last Name <span style="color: red">*</span></label>
          <input type="text" class="form-control" id="lastName" placeholder="Enter your Last name" name="lastName" required />
        </div>

        <div class="mb-3">
          <label for="mobileNumber" class="form-label">Mobile Number </label>
          <input type="tel" class="form-control" id="mobileNumber" placeholder="Enter your mobile number" name="mobilenumber" />
        </div>

        <div class="mb-3">
          <label for="emailAddress" class="form-label">Email Address <span style="color: red">*</span></label>
          <input type="email" class="form-control" id="emailAddress" placeholder="Enter your email address" name="emailaddress" required />
        </div>

        <!-- Payment Method Dropdown -->
        <div class="mb-3">
          <label for="paymentMethod" class="form-label">Payment Method <span style="color: red">*</span></label>
          <select class="form-control" id="paymentMethod" name="paymentMethod" required onchange="toggleRecurringOption()">
              <option value="mobile_money">Mobile Money</option>
              <option value="card">Card</option>
          </select>
        </div>

        <!-- Recurring Option (Only for Card) -->
        <div class="mb-3" id="recurringOption" style="display: none;">
            <div class="form-check"></div>
          <input class="form-check-input" type="checkbox" id="recurring" name="recurring" value="yes">
          <label class="form-check-label" for="recurring">
              Recurring Payment
          </label>
            </div>
      

        <!-- Subscription Period -->
        <div class="mb-3">
            <label for="subscriptionPeriod" class="form-label">Subscription Period <span style="color: red">*</span></label>
            <!-- Subscription Dropdown in HTML -->
<select class="form-control" id="subscriptionPeriod" name="subscriptionPeriod" required onchange="updateAmount()">
    <option value="">Select a Plan</option>
    <?php foreach ($subscriptions as $sub): ?>
        <option value="<?= $sub['duration_days'] ?>" data-price="<?= $sub['price'] ?>">
            <?= $sub['plan_name'] ?> - K<?= number_format($sub['price'], 2) ?>
        </option>
    <?php endforeach; ?>
</select>
        </div>

        <!-- Amount Display -->
        <div class="mb-3 d-flex align-items-center">
            <label for="amount" class="form-label me-5 fixed-width-label">To Pay K</label>
            <div class="input-group flex-grow-1">
                <input type="text" class="form-control no-border" id="amount" style="font-size: 30px" name="amount" readonly />
            </div>
        </div>

        <button type="submit" class="btn btn-success" style="float: right">Click To Pay</button>
      </form>
    </div>
  </div>
</div>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.0.0-beta2/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://pay.lenco.co/js/v1/inline.js"></script>

    <script>
        function handlePayment(event) {
            event.preventDefault();

            const firstName = document.getElementById('firstName').value;
            const lastName = document.getElementById('lastName').value;
            const email = document.getElementById('emailAddress').value;
            const amount = document.getElementById('amount').value;
            const mobileNumber = document.getElementById('mobileNumber').value;
            const subscriptionPeriod = document.getElementById('subscriptionPeriod').value;
            const recurring = document.getElementById('recurring').checked ? 1 : 0;
            getPaidWithDPO(email, firstName, lastName, amount, mobileNumber,recurring, subscriptionPeriod);
        }


  function getPaidWithLenco(email, firstName, lastName, amount, phone) {
    LencoPay.getPaid({
      key: "pub-c42c8102228737069db5da3d6df1f72bcbd9a5094bf00ad3", // your Lenco public key
      reference: "ref-" + Date.now(), // a unique reference you generated
      email: email, // the customer's email address
      amount: amount, // the amount the customer is to pay in cents
      currency: "ZMW",
      channels: ["card", "mobile-money"],
      customer: {
        firstName: firstName,
        lastName: lastName || '', // in case there's no last name
        phone: phone,
      },
      onSuccess: function (response) {
        const fullName = document.getElementById('fullName').value;
        const mobileNumber = document.getElementById('mobileNumber').value;
        window.location = "https://membership.buyingpropertyinzambia.com/payment_success.php?token=" + response.id +
                          "&amount=" + response.amount +
                          "&fullname=" + encodeURIComponent(fullName) +
                          "&mobilenumber=" + encodeURIComponent(mobileNumber) +
                          "&emailaddress=" + encodeURIComponent(email);
      },
      onClose: function () {
        alert("Payment was not completed, window closed.");
      },
      onConfirmationPending: function () {
        alert("Your purchase will be completed when the payment is confirmed");
      },
    });
  }




  function getPaidWithDPO(email, firstName, lastName, amount, phone, recurring, subscriptionPeriod) {
  // Perform the fetch request
  fetch("<?= $base_url ?>/membership/process_dpo.php", { // Ensure process_dpo.php is correctly set up to handle requests
      method: "POST",
      headers: { "Content-Type": "application/json" },
      body: JSON.stringify({
          email: email,
          firstName: firstName,
          lastName: lastName || '',  // Ensure lastName is either the provided value or an empty string
          phone: phone,
          amount: amount,
          currency: "ZMW", // Change this if necessary
          serviceType: "54841", // Update based on the service you are charging for
          description: "Payment for services",
          isRecurring: recurring,  // Pass the computed allowRecurrent
          subscriptionPeriod: subscriptionPeriod  // Add the subscription period
      })  
    })
    .then(response => response.json())
    .then(data => {
        if (data.transToken) {
            // Redirect to the DPO payment page with the transaction token
            window.location.href = "https://secure.3gdirectpay.com/payv3.php?ID=" + data.transToken;
        } else {
            // Handle error if transToken is not present
            alert("Payment failed: " + (data.error || "Transaction token not found"));
        }
    })
    .catch(error => {
        console.error("Error processing payment:", error);
        alert("Payment request failed. Please try again.");
    });
}





function toggleRecurringOption() {
        const paymentMethod = document.getElementById('paymentMethod').value;
        const recurringOption = document.getElementById('recurringOption');

        if (paymentMethod === 'card') {
            recurringOption.style.display = 'block';
        } else {
            recurringOption.style.display = 'none';
        }
    }

    function updateAmount() {
    const select = document.getElementById('subscriptionPeriod');
    const selectedOption = select.options[select.selectedIndex];
    const price = selectedOption.getAttribute('data-price') || '0';
    document.getElementById('amount').value = price;
}

</script>

  </body>
</html>
