<?php
require_once 'vendor/autoload.php';
require_once 'config.php';
// Proceed with your database connection
$host = DATABASE_HOST;
$dbname = DATABASE_NAME;
$username = DATABASE_USER;
$password = DATABASE_PASSWORD;

try {
    // Create PDO connection
    $pdo = new PDO("mysql:host=$host;dbname=$dbname", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // SQL query to fetch all subscription transactions
    $sql = "SELECT * FROM transactions WHERE is_recurring = 1"; // Adjust condition if needed
    $stmt = $pdo->prepare($sql);
    $stmt->execute();
    $transactions = $stmt->fetchAll(PDO::FETCH_ASSOC);

} catch (PDOException $e) {
    echo "Error: " . $e->getMessage();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>DPO Subscription Transactions</title>

    <!-- Bootstrap CDN -->
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">

    <!-- DataTables CSS -->
    <link rel="stylesheet" type="text/css" href="https://cdn.datatables.net/1.10.21/css/jquery.dataTables.min.css">

    <!-- DataTables Buttons CSS -->
    <link rel="stylesheet" type="text/css" href="https://cdn.datatables.net/buttons/2.1.0/css/buttons.dataTables.min.css">

    <!-- jQuery, DataTables JS -->
    <script type="text/javascript" charset="utf8" src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script type="text/javascript" charset="utf8" src="https://cdn.datatables.net/1.10.21/js/jquery.dataTables.min.js"></script>

    <!-- DataTables Buttons JS -->
    <script type="text/javascript" charset="utf8" src="https://cdn.datatables.net/buttons/2.1.0/js/dataTables.buttons.min.js"></script>

   
    <script>
        $(document).ready(function() {
            // Initialize DataTable with buttons
            $('#transactionTable').DataTable({
                dom: 'Bfrtip', // Buttons container
                buttons: [
                    'copy', 'csv', 'excel', 'pdf' // Export buttons
                ]
            });
        });

    </script>



<style>
      .menu-item {
        color: purple;
        border: 1px solid purple;
        padding: 5px 10px;
        border-radius: 5px;
        margin: 0 5px;
      }
      .centered-form {
        min-height: calc(100vh - 250px);
      }
      .no-border {
        border: none;
        background-color: transparent;
        outline: none;
      }

      .no-border[readonly] {
        background-color: transparent;
      }

      .d-flex {
        display: flex;
      }

      .align-items-center {
        align-items: center;
      }

      .me-2 {
        margin-right: 0.2rem; /* Adjust the margin as needed */
      }

      .fixed-width-label {
        white-space: nowrap;
        width: 80px; /* Adjust the width as needed */
      }

      .flex-grow-1 {
        flex-grow: 1;
      }

      .buttont {
        background-color: #622d80;
        border: 0;
      }

      .buttont:hover {
        background-color: #c39bd3; /* A light shade of purple */
      }
    </style>
</head>
<body>



<header class="bg-light py-3">
      <div class="container">
        <div class="d-flex flex-wrap align-items-center">
          <div class="logo">
            <img src="assets/img/logo.png" alt="Logo" class="img-fluid" />
          </div>
          <nav class="ms-auto">
            <ul class="nav">
              <li class="nav-item">
                <a
                  class="nav-link menu-item"
                  href="https://buyingpropertyinzambia.com/"
                  >Home</a
                >
              </li>
            </ul>
          </nav>
        </div>
      </div>
    </header>

    <div class="container mt-5">
    <h2 class="text-center mb-4">DPO Subscription Transactions</h2>

    <div class="card shadow">
    <div class="card-body">
        <div class="table-responsive">
            <table id="transactionTable" class="table table-bordered table-striped">
                <thead class="thead-dark">
                    <tr>
                        <th>ID</th>
                        <th>Company Ref</th>
                        <th>Amount</th>
                        <th>Email</th>
                        <th>First Name</th>
                        <th>Last Name</th>
                        <th>Phone</th>
                        <th>Subscription Period</th>
                        <th>Is Recurring</th>
                        <th>Transaction Token</th>
                        <th>Company Token</th>
                        <th>Transaction Status</th> <!-- Updated to transaction_status -->
                        <th>Expiry Date</th> <!-- Updated to expiry_date -->
                        <th>Created At</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    // Iterate through each transaction to display data
                    foreach ($transactions as $transaction) {
                        echo "<tr>";
                        echo "<td>" . $transaction['id'] . "</td>";
                        echo "<td>" . $transaction['company_ref'] . "</td>";  // Updated to company_ref
                        echo "<td>" . $transaction['amount'] . "</td>";  // Updated to amount
                        echo "<td>" . $transaction['email'] . "</td>";  // Updated to email
                        echo "<td>" . $transaction['first_name'] . "</td>";  // Updated to first_name
                        echo "<td>" . $transaction['last_name'] . "</td>";  // Updated to last_name
                        echo "<td>" . $transaction['phone'] . "</td>";  // Updated to phone
                        echo "<td>" . $transaction['subscription_period'] . "</td>";  // Updated to subscription_period
                        echo "<td>" . ($transaction['is_recurring'] == 1 ? 'Yes' : 'No') . "</td>";  // Updated to is_recurring
                        echo "<td>" . $transaction['trans_token'] . "</td>";  // Updated to trans_token
                        echo "<td>" . $transaction['company_token'] . "</td>";  // Updated to company_token
                        echo "<td>" . $transaction['transaction_status'] . "</td>";  // Updated to transaction_status
                        echo "<td>" . $transaction['expiry_date'] . "</td>";  // Updated to expiry_date
                        echo "<td>" . $transaction['created_at'] . "</td>";  // Updated to created_at
                        echo "</tr>";
                    }
                    ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

</div>


    <!-- Bootstrap JS -->
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>


    <!-- DataTables Buttons JS and dependencies -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.1.3/jszip.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js"></script>
<script src="https://cdn.datatables.net/buttons/2.1.0/js/buttons.html5.min.js"></script>
<script src="https://cdn.datatables.net/buttons/2.1.0/js/buttons.print.min.js"></script>

</body>
</html>
